==> ifpgui_0.10.8.orig.tar.gz: ifpgui-0.10.8/src/revision.cpp <==
/***************************************************************************
 *   Copyright (C) 2004-2006 by Jim Campbell                             *
 *   ifpgui@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/
/***************************************************************************
   0.7.0
   2005-06-19
        - Added check box menu item to convert the *.REC
           files to mp3 files.
           This is still incomplete because I do not have
           access to any REC files in the iRiver format.

   0.8.0
   2005-07-09
        - Added support for uploading files using a
           playlist.  Currently only m3u files are
           supported.  If the need arrises other formats
           can be supported as well.

   0.8.1
   2005-07-15
        - Fixed bug with deleting a directory and some
           files from iFP device.
        - Fixed bug with uploading a directory and some
           files to iFP device. It used to upload the
           files under the directory and also upload the
           directory (including the files).  So you got
           the files twice.
        - Fixed same bug as above, but for download.
        - Fixed refreshing and current file/directory
           selection after upload or download.  Now it
           places the current item in a better place and
           also selects/opens the item to show the contents.
        - Fixed the progress dialog.  It never shows
           multiple dialogs for one user initiated transfer.
           All transfers are shown with two progress bars
           (one for total progress and one for current file
           progress).  The only exception is when the user
           is actually transfering only one file.

   0.8.5
   2005-07-16
        - Added preliminary support for multi-national
           filename support.

   0.9.1
   2005-07-27
        - Rearanged menus to look similar to windows version
           of iRiver Manager.
        - Added horizontal and vertical view alignments.
        - Progress dialog appears after a yes/yes all to
           confirm action.
        - Dialogs to confirm action are better worded.

   0.9.2
   2005-07-31
        - Added support for drag drop from Konqueror and Nautilus.
   0.9.3
   2005-08-04
        - Put project on CVS
        - Implemented dialogs to show while deleting files
           and directories.  There is still a problem with
           deleting just one file or directory.  The
           dialog shows but there is nothing in it.  It
           seems to be random because sometimes it works.
   2005-08-07
        - Added check for sane values when reading from settings file.
        - Changed the update firmware and format icons
   2005-08-24
        - Patched libifp files into ifp_gui.
        - Fixed support for deleting local files and directories with
           multi-national characters.
        - Fixed some anomalies with the handling of the selected item
           within the file trees.  Mainly dealing with what happens
           after an item is deleted.
   2005-09-02
        - Just a little code cleanup in ifpviewer.cpp and fileviewer.cpp
        - Fixed Delete tool button to check the window with focus before
           calling the appropriate delete function.
   0.10.1
   2005-09-21
        - Made an I/O interface so that all function dealing with the
           file systems can be centralized.  All local functions are
           handled from one class and all ifp functions are handled from
           another class.  Both classes are decendants of a base i/o
           class.
        - Made a major overhall to the internals of the GUI to use the
           new I/O interface classes.  This includes the removal of
           ifpviewer.cpp and ifpviewer.h.  There is now only one widget
           that supports the viewing of files.  This widget is a now the
           fileviewer.cpp class and functions; but all the backend is
           handled by the I/O interface class.  In theory, any protocol
           can be added to the I/O interface and the file viewer can use
           this new protocol seemlessly.
   2005-09-28
        - Changes to dialogs.  All Yes/No and OK dialogs use a standard
           function for their display.  The dialogs come to the front
           when they popup.  Also the progress dialog now is a stay-on-
           top dialog that will minimize with the application.
   2005-10-03
        - Added a toolbar to the file viewer.  Now the standard file
           system functions will be accessable via an attached toolbar.
           These functions include: up one directory, refresh, new
           directory, properties, rename and delete.
   2005-10-06
        - Fixed several bugs:
           Making directories would not put selected node at new directory.
           Menu items, delete, rename, mkdir, etc were not working.
           Different file picker for Upload Playlist and Update Firmware.
           About QT broken
           Buttons would do nothing when clicked when iRiver not plugged in.
           Filelist would not clear on disconnect.
   0.10.2
   2005-10-07
        - Added Icons to menu commands.
   2005-10-10
        - Fixed Format, was not showing a message stating what it was doing.
           Also the file list was not refreshed.
        - Another fix with create directory.  The cancel was showing a
           message even though the uses chose cancel.
   0.10.3
   2005-10-07
        - Added #include <errno.h> to iointerface.cpp
   0.10.4
   2005-10-19
        - Fixed support for utf-8.  All buffers to and from the ifp library
           are converted to utf-8 compatable buffers. (I hope).
   0.10.5
   2005-10-27
        - Applied patch from Sergey V Turchin for adding translations.
        - Added the Russian translation from Sergey V Turchin.
   2005-11-19
        - Finished translation stuff.
   0.10.6
   2005-12-02
        - Added patch by John Steele Scott to support directories that are
           symbolic links.
        - Changed name back to ifpgui.
        - Added Ubuntu Debian package support files under the debian directory
   2005-12-17
        - Moved the SuSE spec file to the suse directory.
   0.10.7
   2006-01-22
        - Added Translation for Danish and German
           Danish translation added by Jørgen Elgaard Larsen
           German translation added by Peter Bittner
        - Fixed some translations problems.
   0.10.8
   2006-05-24
        - Added patch from d-frog to fix renaming directories
           and then doing a refresh.
***************************************************************************/
#include <qstring.h>

QString AppRevision = "ifpgui-0.10.7";
QString LibRevision = "libifp-1.0.0.2";

==> ifpgui_0.12.0.orig.tar.gz: ifpgui-0.12.0/src/revision.cpp <==
/***************************************************************************
 *   Copyright (C) 2004-2006 by Jim Campbell                             *
 *   ifpgui@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/
/***************************************************************************
   0.7.0
   2005-06-19
        - Added check box menu item to convert the *.REC
           files to mp3 files.
           This is still incomplete because I do not have
           access to any REC files in the iRiver format.

   0.8.0
   2005-07-09
        - Added support for uploading files using a
           playlist.  Currently only m3u files are
           supported.  If the need arrises other formats
           can be supported as well.

   0.8.1
   2005-07-15
        - Fixed bug with deleting a directory and some
           files from iFP device.
        - Fixed bug with uploading a directory and some
           files to iFP device. It used to upload the
           files under the directory and also upload the
           directory (including the files).  So you got
           the files twice.
        - Fixed same bug as above, but for download.
        - Fixed refreshing and current file/directory
           selection after upload or download.  Now it
           places the current item in a better place and
           also selects/opens the item to show the contents.
        - Fixed the progress dialog.  It never shows
           multiple dialogs for one user initiated transfer.
           All transfers are shown with two progress bars
           (one for total progress and one for current file
           progress).  The only exception is when the user
           is actually transfering only one file.

   0.8.5
   2005-07-16
        - Added preliminary support for multi-national
           filename support.

   0.9.1
   2005-07-27
        - Rearanged menus to look similar to windows version
           of iRiver Manager.
        - Added horizontal and vertical view alignments.
        - Progress dialog appears after a yes/yes all to
           confirm action.
        - Dialogs to confirm action are better worded.

   0.9.2
   2005-07-31
        - Added support for drag drop from Konqueror and Nautilus.
   0.9.3
   2005-08-04
        - Put project on CVS
        - Implemented dialogs to show while deleting files
           and directories.  There is still a problem with
           deleting just one file or directory.  The
           dialog shows but there is nothing in it.  It
           seems to be random because sometimes it works.
   2005-08-07
        - Added check for sane values when reading from settings file.
        - Changed the update firmware and format icons
   2005-08-24
        - Patched libifp files into ifp_gui.
        - Fixed support for deleting local files and directories with
           multi-national characters.
        - Fixed some anomalies with the handling of the selected item
           within the file trees.  Mainly dealing with what happens
           after an item is deleted.
   2005-09-02
        - Just a little code cleanup in ifpviewer.cpp and fileviewer.cpp
        - Fixed Delete tool button to check the window with focus before
           calling the appropriate delete function.
   0.10.1
   2005-09-21
        - Made an I/O interface so that all function dealing with the
           file systems can be centralized.  All local functions are
           handled from one class and all ifp functions are handled from
           another class.  Both classes are decendants of a base i/o
           class.
        - Made a major overhall to the internals of the GUI to use the
           new I/O interface classes.  This includes the removal of
           ifpviewer.cpp and ifpviewer.h.  There is now only one widget
           that supports the viewing of files.  This widget is a now the
           fileviewer.cpp class and functions; but all the backend is
           handled by the I/O interface class.  In theory, any protocol
           can be added to the I/O interface and the file viewer can use
           this new protocol seemlessly.
   2005-09-28
        - Changes to dialogs.  All Yes/No and OK dialogs use a standard
           function for their display.  The dialogs come to the front
           when they popup.  Also the progress dialog now is a stay-on-
           top dialog that will minimize with the application.
   2005-10-03
        - Added a toolbar to the file viewer.  Now the standard file
           system functions will be accessable via an attached toolbar.
           These functions include: up one directory, refresh, new
           directory, properties, rename and delete.
   2005-10-06
        - Fixed several bugs:
           Making directories would not put selected node at new directory.
           Menu items, delete, rename, mkdir, etc were not working.
           Different file picker for Upload Playlist and Update Firmware.
           About QT broken
           Buttons would do nothing when clicked when iRiver not plugged in.
           Filelist would not clear on disconnect.
   0.10.2
   2005-10-07
        - Added Icons to menu commands.
   2005-10-10
        - Fixed Format, was not showing a message stating what it was doing.
           Also the file list was not refreshed.
        - Another fix with create directory.  The cancel was showing a
           message even though the uses chose cancel.
   0.10.3
   2005-10-07
        - Added #include <errno.h> to iointerface.cpp
   0.10.4
   2005-10-19
        - Fixed support for utf-8.  All buffers to and from the ifp library
           are converted to utf-8 compatable buffers. (I hope).
   0.10.5
   2005-10-27
        - Applied patch from Sergey V Turchin for adding translations.
        - Added the Russian translation from Sergey V Turchin.
   2005-11-19
        - Finished translation stuff.
   0.10.6
   2005-12-02
        - Added patch by John Steele Scott to support directories that are
           symbolic links.
        - Changed name back to ifpgui.
        - Added Ubuntu Debian package support files under the debian directory
   2005-12-17
        - Moved the SuSE spec file to the suse directory.
   0.10.7
   2006-01-22
        - Added Translation for Danish and German
           Danish translation added by Jørgen Elgaard Larsen
           German translation added by Peter Bittner
        - Fixed some translations problems.
   0.10.8
   2006-05-24
        - Added patch from d-frog to fix renaming directories
           and then doing a refresh.
   0.10.9
   2006-09-23
        - in prim.c ifp_file_flush, changed obsene_limit to 100.
           This loop was actually being used and waiting a long time.
        - Errors on upload are no longer hidden behind progress dialog.
        - Playlist directory is saved and restored when loading playlists.
        - File View directory is saved and restored.
   0.12.0
   2007-08-30
        - Added the processingFile flags to ioInterface.
        - Do not update status when isProcessing() is TRUE.
          This fixes a very serious bug the caused upload and download
          corruption.
        - isProcessing() runs from the top leve of the GUI down to the
          ioInterface to determine if the application is transfering files.
        - minor changes to the directory structure.
***************************************************************************/
#include <qstring.h>

QString AppRevision = "ifpgui-0.12.0";
QString LibRevision = "libifp-1.0.0.3";
